div.window.active {
  display: block;
}

div.window {
  display: none;
}

input[type="hidden"] {
  display: none;
}

body {
  margin: 0;
  padding: 0;
}

ul#tabs {
  z-index: 20;
}

ul#tabs li:hover {
  cursor: default;
}

ul#controls {
  z-index: 30;
  background: #ddd;
}

ul#controls li {
  position: relative;
}

select.select_overlay {
  display: block;
  position: absolute;
  top: 0px;
  left: 0px;
  bottom: 0px;
  width: 22px;
  border: none;
  padding: 0;
  margin: 0;
  opacity: 0;
  font-size: 12px;
}

select#tab_overflow_overlay option.unread {
  font-weight: bold;
}

body {
  font-family: "Lucida Grande", Helvetica, sans-serif;
  background: #fff;
}

a:link, a:visited, a:hover, a:active { color:#0033cc; }

a:hover {
  text-shadow: rgba( 0, 0, 0, .3 ) 0 1px 1px;
}

div.window {
  position:fixed;
  top: 0px;
  left: 0px;
  right: 0px;
  bottom: 23px;
}

div.window table {
  width: 100%;
  height: 100%;
  padding: 0;
}

tr.input td {
  height: 20px;
  background: #efefef;
  border-bottom: 1px solid #999;
}

tr.vert_dragger td {
  height: 3px;
  background: #efefef;
  border-top: 1px solid #aaa;
}

tr.input textarea {
  width: 100%;
  padding: 3px 0;
  border: none;
  margin: 0;
  outline: 0 none;
  font-size: 12px;
  overflow: hidden;
  resize: none;
  font-family: "Lucida Grande", Helvetica, sans-serif;
}

tr.input input.send {
  display: none;
}

div#tab_container {
  position: fixed;
  bottom: 0px;
  left: 0px;
  right: 0px;
  height: 23px;
  background: #ddd;
  
}

ul#tabs {
  list-style: none;
  margin: 0;
  padding: 0;
  font-size: 11px;
  position: relative;
  float: left;
  margin-right: 62px;
  padding-left: 3px;
}

ul#tabs li {
  float: left;
  margin: 0;
  margin-left: -1px;
  color: #333;
  background: #ddd;
}

ul#tabs li:first-child div.hit_area {
  border-left: 1px solid #ddd;
}

ul#tabs li div.hit_area {
  border: 1px solid #999;
  border-bottom: none;
  border-top: none;
  float:left;
  height: 14px;
  padding: 2px 10px 8px 4px;
}

ul#tabs li.active div.hit_area {
  border: 1px solid #999;
  border-top: none;
  background: #efefef;
  height: 11px;
  padding-top: 3px;
  margin-top: -1px;
}

ul#tabs li.active {
  height: 23px;
  z-index: 21;
}

ul#tabs li.active:hover div.hit_area {
  background: #efefef;
}

ul#tabs li:hover div.hit_area {
  background: #ccc;
}

ul#controls {
  position: fixed;
  bottom: 0px;
  right: 0px;
  height: 23px;
  margin: 0;
  padding: 0 18px 0 0;
  list-style: none;
}

ul#controls li {
  float: right;
  margin: 0;
  padding: 0;
  height: 16px;
  width: 16px;
  padding: 4px 3px 3px 3px;
  cursor: pointer;
}

ul#controls li:hover {
  background: #ccc;
}

tr.topic td {
  width: 100%;
  background: #efefef;
  font-size: 11px;
  text-align: center;
  border-top: 1px solid #fff;
  border-bottom: 1px solid #aaa;
  padding: 1px 0;
  height: 1.2em;
  overflow: hidden;
}

tr.topic a {
  text-decoration: none;
}

div.message_wrap {
  height: 100%;
  overflow-x: none;
  overflow-y: auto;
  background: #fff;
}

ul.messages {
  list-style: none;
  margin: 0;
  padding: 0;
  overflow: hidden;
  background: url(image/background.png) top left repeat-y;
  margin: 3px 0;
}

ul.messages li {
  font-size: 13px;
  display: block;
  position: relative;
}

ul.messages li:not(.consecutive) {
  clear: both;
}

#info ul.messages li.highlight,
ul.messages li.self {
  background: url(image/background-self.png) top left repeat-y #fffbd0;
}

#info ul.messages li.highlight div.msg,
ul.messages li.self div.msg {
  background: none;
}

ul.messages li.consecutive div.left {
  display: none;
}

div.left {
  float: left;
  width: 127px;
  font-weight: bold;
  text-align: right;
  padding: 4px 0;
  padding-right: 4px;
  padding-bottom: 0;
  text-overflow: ellipsis;
  position: relative;
}

li.event div.left {
  padding-top: 5px;
}

li.event div.msg {
  border-top: none;
}

ul.messages li.avatar div.left {
  padding-bottom: 3px;
  padding-top: 3px;
}

li.event div.left {
  padding: 5px 0;
  width: 125px;
}

ul.messages li.avatar {
  z-index: 999;
}

div.left img {
  border: 1px solid #fff;
  display: block;
  width: 32px;
  height: 32px;
  float: right;
}

div.left span.nickhint {
  position: absolute;
  z-index: 999;
  right: 5px;
  top: 4px;
  padding: 0 2px;
  min-width: 28px;
  background: rgba(0, 0, 0, 0.5);
  color: #fff;
  text-shadow: rgba( 0, 0, 0, 1 ) 0 1px 1px;
  opacity: 0;
  -webkit-transition: opacity 0.5s ease-in-out;
}

div.timehint {
  position: absolute;
  font-size: 10px;
  right: 0px;
  top: 1px;
  padding: 6px 4px 2px 4px ;
  color: #555;
  opacity: 0;
  text-shadow: rgba(255,255,255,1) 0 0 3px;
  background: #fff;
}

#info ul.messages li.highlight div.timehint,
li.self div.timehint {
  background: #fffbd0;
}

div.msg {
  margin-left: 132px;
  padding: 3px 5px;
  word-wrap: break-word;
  -khtml-line-break: after-white-space;
  -khtml-nbsp-mode: space;
  border-top: 1px solid #eee;
}

li.event div.msg {
  padding: 5px;
}

li.monospace div.msg {
  padding: 6px 5px;
}

li.event + li.message div.msg {
  border-top: 1px solid transparent;
}

ul.messages li:first-child div.msg {
  border-top: 1px solid transparent;
}

/* so the last avatar doesn't hang off the edge */
ul.messages li.avatar:last-child {
  min-height: 42px;
}

ul.messages li.monospace {
  min-height: 0px;
}

ul.messages li.message:last-child {
  border-bottom: 1px solid #eee;
}

ul.messages li.consecutive div.msg {
  border-top: none;
}

ul.messages li + li.consecutive div.msg {
  padding-top: 0px;
}

div.msg a {
  word-break: break-all;
}

div.msg img {
  display: block;
  border: none;
}

ul.messages li.monospace + li.monospace.consecutive {
  margin-top: -5px;
}

ul.messages li.monospace div.msg {
  font-family: Monaco, monospace;
  font-size: 10px;
  line-height: 12px;
  word-wrap: normal;
  white-space: pre-wrap;
}

li.monospace span[style*="bold"] div.msg {
  letter-spacing: -1px;
}

ul.messages li.event {
  font-size: 11px;
  background: #d9e7fb;
  border-bottom: 1px solid #fff;
}

ul.messages li.event div.msg {
  background: none;
  border-left: none;
}

ul.messages li.event div.left {
  font-weight: normal;
}

ul.messages li.announce div.msg {
  color: #777;
  white-space: pre-wrap;
}

div.msg img.audio {
  cursor: pointer;
  display: inline;
  padding: 0 4px;
  width: 16px;
  height: 16px;
  margin-bottom: -3px;
}

a.nick {
  color: #000;
  text-decoration: none;
}

div.tab_button {
  width: 16px;
  height: 16px;
  float: left;
  margin-right: 6px;
}

li.channel_tab div.tab_button {
  background: url(image/roomTab.png);
}

li.privmsg_tab div.tab_button {
  background: url(image/privateChatTab.png);
}

li.info_tab div.tab_button {
  background: url(image/smartTranscriptTab.png);
}

li.info_tab div.tab_button {
  background: url(image/smartTranscriptTab.png);
}

ul#tabs li.active div.tab_button:hover {
  background: url(image/aquaTabClose.png) no-repeat center;
}

ul#tabs li.unread.channel_tab div.tab_button {
  background: url(image/roomTabNewMessage.png);
}

ul#tabs li.unread.privmsg_tab div.tab_button {
  background: url(image/privateChatTabNewMessage.png);
}

ul#tabs li.unread.info_tab div.tab_button {
  background: url(image/smartTranscriptTabActivity.png);
}

ul#tabs li.highlight.channel_tab div.tab_button {
  background: url(image/roomTabNewHighlightMessage.png);
}

div.autocomplete ul {
  height: 1.6em;
  position: absolute;
  bottom: 20px;
  list-style: none;
  margin: 0;
  padding: 0;
  border-top: 1px solid #ccc;
  background: #fff;
  font-size: 0.8em;
}

div.autocomplete ul li.selected { background-color: #ffb; text-decoration: underline;}

div.autocomplete ul li {
  float: left;
  height: 1.2em;
  margin: 0;
  padding: 0.2em 5px;
  border-right: 1px solid #ccc;
}

div#config {
  position: absolute;
  width: 480px;
  top: 5px;
  bottom: 5px;
  background: #efefef;
  padding: 10px 10px;
  z-index: 999;
}

div#config div#buttons {
  position: absolute;
  bottom: 10px;
  left: 170px;
}

div#config div.setting {
  margin-top: 0.5em;
  margin-left: 160px;
  display: none;
}

div#config div.setting.active {
  display: block;
}

div#config div.setting div.field {
  float: left;
  margin-bottom: 10px;
  margin-right: 8px;
}

div#config div.setting div.field.clear {
  clear: both;
}

div#config label, div#config input {
  display: block;
  font-size: 0.8em;
}

div#config span {
  font-size: 0.8em;
}

div#config select {
  width: 135px;
  height: 100px;
  font-size: 0.8em;
    outline: 0 none;
}

div#config div#server_controls {
  position: absolute;
  bottom: 18px;
  left: 6px;
}

div#config div.controls {
  clear: both;
  font-size: 0.7em;
}

div#config div.controls a {
  text-decoration: none;
  margin: 0 5px 0 0;
}

div#config div.controls a:hover {
  text-shadow: none;
  text-decoration: underline;
}

div#config label {
  color: #666;
}

div#config ul#connections {
  list-style: none;
  position: absolute;
  top: 5px;
  bottom: 32px;
  left: 5px;
  margin: 0;
  padding: 0px;
  width: 150px;
  background: #fff;
  border-right: 1px solid #ccc;
  border-bottom: 1px solid #ccc;
}

div#config ul#connections li.header {
  background: #efefef;
  text-transform: uppercase;
  color: #777;
  letter-spacing: 1px;
  font-size: 0.7em;
  cursor: default;
}

div#config ul#connections li.header:hover {
  background: #efefef;
}

div#config ul#connections li {
  padding: 5px 8px;
  font-size: 0.9em;
  cursor: pointer;
    border: 1px solid #fff;
    border-bottom: none;
}

div#config ul#connections li:hover {
  background: #ffffcc;
}

div#config ul#connections li.disconnected.active,
div#config ul#connections li.connected.active {
  background: #3875d7;
  color: #fff;
}

div#config ul#connections li.disconnected {
  color: #999;
}

div#config ul#connections li.connected {
  color: #222;
}

body.config {
  background: #efefef;
}

div#logsearch {
  background: #eee;
  border-bottom: 1px solid #999;
  position: fixed;
  top: 0px;
  left: 0px;
  right: 0px;
  height: 28px;
  padding: 5px 0 0 0;
}

div#logsearch label {
  font-size: 0.7em;
  padding-right: 2px;
  padding-left: 10px;
  color: #666;
}

div#logsearch form {
  display: block;
  margin: 0;
}

ul#logresults {
  list-style: none;
  margin: 0;
  padding: 0;
  position: absolute;
  top: 34px;
  bottom: 0px;
  left: 0px;
  right: 0px;
  overflow: auto;
}

ul#logresults li {
  border-bottom: 1px solid #eee;
  padding: 0;
  font-size: 0.8em;
  cursor: pointer;
}

ul#logresults div.focus:hover {
  background: #eee;
}

ul#logresults li div.focus {
  background: #fff;
  padding: 5px 10px;
}

ul#logresults li.context div.focus:hover {
  background: #fff;
}

ul#logresults li.context ul {
  margin: 0;
  padding: 5px 10px;
  list-style: none;
}

ul#logresults li.context ul li {
  border: none;
  margin: 0;
  padding: 2px 0;
}

ul#logresults li.context {
  border-top: 1px solid #999;
  border-bottom: 1px solid #999;
  background: url(image/shadow-bottom.png) bottom left repeat-x, url(image/shadow-top.png) top left repeat-x #eee;
}

ul#logresults span.metadata {
  font-size: 0.7em;
  color: #666;
}
